@@ -23,7 +23,7 @@ Options:
 import os
 import json
 import requests
-import urllib
+import uuid
 from typing import Any, List
 
 import pandas as pd
@@ -254,11 +254,13 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
                 alternatives = [alternatives]
             if isinstance(alternatives, dict) and "alternatives" in alternatives:
                 alternatives = alternatives["alternatives"]
+            existing_id = safe_row["conversation_uuid"]
+            dedupe_id = uuid.uuid4().hex
 
             dataset.append({
                 "priority": 1,
                 "data_source": "fsm",
-                "data_id": safe_row["conversation_uuid"],
+                "data_id": f"{existing_id}--{dedupe_id}",
                 "data": {
                     "call_uuid": safe_row["call_uuid"],
                     "conversation_uuid": safe_row["conversation_uuid"],
